@@ -75,6 +75,7 @@ static const char *os[][2] = {
   {"iPad", "iOS"},
   {"iPod", "iOS"},
   {"iPhone", "iOS"},
+  {"CFNetwork", "iOS"},
   {"AppleTV", "iOS"},
   {"iTunes", "Macintosh"},
   {"OS X", "Macintosh"},
@@ -90,20 +91,26 @@ static const char *os[][2] = {
   {"Gentoo", "Linux"},
   {"CentOS", "Linux"},
   {"PCLinuxOS", "Linux"},
-  {"Linux", "Linux"},
-  {"linux", "Linux"},
+  {"Arch", "Linux"},
+  {"Parabola", "Linux"},
 
   {"FreeBSD", "BSD"},
   {"NetBSD", "BSD"},
   {"OpenBSD", "BSD"},
   {"DragonFly", "BSD"},
+
   {"PlayStation", "BSD"},
 
+  {"Linux", "Linux"},
+  {"linux", "Linux"},
+
   {"CrOS", "Chrome OS"},
-  {"SunOS", "Unix-like"},
   {"QNX", "Unix-like"},
   {"BB10", "Unix-like"},
 
+  {"AIX", "Unix"},
+  {"SunOS", "Unix"},
+
   {"BlackBerry", "Others"},
   {"Sony", "Others"},
   {"AmigaOS", "Others"},
@@ -351,6 +358,11 @@ parse_os (const char *str, char *tkn, char *os_type, int idx) {
     return conf.real_os ? get_real_android (tkn) : xstrdup (tkn);
   }
   /* iOS */
+  if ((strstr (tkn, "CFNetwork")) != NULL) {
+    if ((b = strchr (str, ' ')))
+      *b = 0;
+    return xstrdup (str);
+  }
   if (strstr (tkn, "iPad") || strstr (tkn, "iPod"))
     return xstrdup (parse_ios (tkn, 4));
   if (strstr (tkn, "iPhone"))
